<?php
namespace wcf\page;
use wcf\data\category\CategoryNodeTree;
use wcf\system\category\CategoryHandler;
use wcf\system\user\collapsible\content\UserCollapsibleContentHandler;
use wcf\system\WCF;

/**
 * Shows the terms of use page.
 * 
 * @author	Sascha Greuel <sascha@softcreatr.de>
 * @copyright	2013 Sascha Greuel
 * @license	Creative Commons Attribution-NoDerivatives <http://creativecommons.org/licenses/by-nd/4.0/legalcode>
 * @package	be.bastelstu.sascha.termsofuse
 * @subpackage	page
 * @category	Community Framework
 */
class TermsOfUsePage extends AbstractPage {
	/**
	 * @see	\wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = 'wcf.footer.menu.termsOfUse';
	
	/**
	 * @see	\wcf\page\AbstractPage::$enableTracking
	 */
	public $enableTracking = true;
	
	/**
	 * @see	\wcf\page\AbstractPage::$neededModules
	 */
	public $neededModules = array('MODULE_USER_TERMS_OF_USE');
	
	/**
	 * @see	\wcf\page\AbstractPage::$templateName
	 */
	public $templateName = 'termsOfUseShow';
	
	/**
	 * category object type object
	 * @var	\wcf\data\object\type\ObjectType
	 */
	public $objectType = null;
	
	/**
	 * category node tree
	 * @var	\wcf\data\category\CategoryNodeTree
	 */
	public $categoryNodeTree = null;
	
	/**
	 * @see	\wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		$this->objectType = CategoryHandler::getInstance()->getObjectTypeByName('be.bastelstu.sascha.termsofuse.term');
		$this->buildCategoryNodeTree();
	}
	
	/**
	 * @see	\wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'terms' => $this->categoryNodeTree->getIterator(),
			'sidebarCollapsed' => UserCollapsibleContentHandler::getInstance()->isCollapsed('com.woltlab.wcf.collapsibleSidebar', 'be.bastelstu.sascha.termsofuse.TermsOfUsePage'),
			'sidebarName' => 'be.bastelstu.sascha.termsofuse.TermsOfUsePage',
			'allowSpidersToIndexThisPage' => true
		));
	}
	
	/**
	 * Reads available terms.
	 */
	protected function buildCategoryNodeTree() {
		$this->categoryNodeTree = new CategoryNodeTree($this->objectType->objectType, 0, false);
	}
}
